# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.indexing_task_resource_api import IndexingTaskResourceApi


class TestIndexingTaskResourceApi(unittest.TestCase):
    """IndexingTaskResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = IndexingTaskResourceApi()

    def tearDown(self) -> None:
        pass

    def test_create_indexing_task(self) -> None:
        """Test case for create_indexing_task

        Create Indexing Task
        """
        pass

    def test_get_indexing_task(self) -> None:
        """Test case for get_indexing_task

        Get Indexing Task
        """
        pass

    def test_list_indexing_actions(self) -> None:
        """Test case for list_indexing_actions

        List Indexing Actions
        """
        pass

    def test_start_execution(self) -> None:
        """Test case for start_execution

        Start Execution
        """
        pass


if __name__ == '__main__':
    unittest.main()
