# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.action_type import ActionType

class TestActionType(unittest.TestCase):
    """ActionType unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testActionType(self):
        """Test ActionType"""
        # inst = ActionType()

if __name__ == '__main__':
    unittest.main()
