# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.uri_resource_api import UriResourceApi


class TestUriResourceApi(unittest.TestCase):
    """UriResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = UriResourceApi()

    def tearDown(self) -> None:
        pass

    def test_add_tag_to_file(self) -> None:
        """Test case for add_tag_to_file

        Add Tag To File
        """
        pass

    def test_create_uri_folder(self) -> None:
        """Test case for create_uri_folder

        Create Folder
        """
        pass

    def test_create_uri_folder_v2(self) -> None:
        """Test case for create_uri_folder_v2

        Create folder and return its URI
        """
        pass

    def test_download_resource(self) -> None:
        """Test case for download_resource

        Download Resource
        """
        pass

    def test_get_metadata_from_uri(self) -> None:
        """Test case for get_metadata_from_uri

        Get Metadata
        """
        pass

    def test_get_parent(self) -> None:
        """Test case for get_parent

        Get Parent
        """
        pass

    def test_get_signed_url_from_uri(self) -> None:
        """Test case for get_signed_url_from_uri

        Get Signed Url
        """
        pass

    def test_list_files(self) -> None:
        """Test case for list_files

        List Files
        """
        pass

    def test_list_resources(self) -> None:
        """Test case for list_resources

        List Resources
        """
        pass

    def test_remove_resource(self) -> None:
        """Test case for remove_resource

        Remove Resource
        """
        pass

    def test_remove_tag_from_file(self) -> None:
        """Test case for remove_tag_from_file

        Remove Tag From File
        """
        pass

    def test_upload_resource(self) -> None:
        """Test case for upload_resource

        Upload
        """
        pass

    def test_upload_resource_v2(self) -> None:
        """Test case for upload_resource_v2

        Upload file and return the resulting URI
        """
        pass


if __name__ == '__main__':
    unittest.main()
