# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.citations_resource_api import CitationsResourceApi


class TestCitationsResourceApi(unittest.TestCase):
    """CitationsResourceApi unit test stubs"""

    def setUp(self) -> None:
        self.api = CitationsResourceApi()

    def tearDown(self) -> None:
        pass

    def test_get_bulk_citations(self) -> None:
        """Test case for get_bulk_citations

        Get Bulk Citations
        """
        pass

    def test_get_citation_output_uri(self) -> None:
        """Test case for get_citation_output_uri

        Get Citation Output Uri
        """
        pass


if __name__ == '__main__':
    unittest.main()
