# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.list_file_system_response import ListFileSystemResponse

class TestListFileSystemResponse(unittest.TestCase):
    """ListFileSystemResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ListFileSystemResponse:
        """Test ListFileSystemResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ListFileSystemResponse`
        """
        model = ListFileSystemResponse()
        if include_optional:
            return ListFileSystemResponse(
                resources = {
                    'key' : perceptic_core_client.models.resource_metadata_dto.ResourceMetadataDto(
                        files_system_rid = '', 
                        resource_id = '', 
                        uri = '', 
                        name = '', 
                        type = 'FILE', 
                        path = '', 
                        extension = '', 
                        size_in_bytes = 56, 
                        last_modified = null, 
                        etag = '', 
                        tags = [
                            ''
                            ], )
                    }
            )
        else:
            return ListFileSystemResponse(
        )
        """

    def testListFileSystemResponse(self):
        """Test ListFileSystemResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
