# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class JsonNodeType(str, Enum):
    """
    JsonNodeType
    """

    """
    allowed enum values
    """
    ARRAY = 'ARRAY'
    BINARY = 'BINARY'
    BOOLEAN = 'BOOLEAN'
    MISSING = 'MISSING'
    NULL = 'NULL'
    NUMBER = 'NUMBER'
    OBJECT = 'OBJECT'
    POJO = 'POJO'
    STRING = 'STRING'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of JsonNodeType from a JSON string"""
        return cls(json.loads(json_str))


