# coding: utf-8

# flake8: noqa

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "CitationsResourceApi",
    "ConnectionResourceApi",
    "FileSystemContentsResourceApi",
    "FileSystemResourceApi",
    "IndexerResourceApi",
    "IndexingScheduleResourceApi",
    "IndexingTaskResourceApi",
    "TagResourceApi",
    "UriResourceApi",
    "UserResourceApi",
    "WorkerResourceApi",
    "WorkflowResourceV3Api",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "ActionType",
    "AddTagToFileRequest",
    "AzureBlobConnectionSettingsApiDto",
    "AzureBlobFileSystemRootMetadataApiDto",
    "BiotechAnalysisApiDto",
    "BiotechAnalysisImageAnnotatedCitationApiDto",
    "BulkGetCitationsRequest",
    "BulkGetCitationsResponse",
    "CitationApiDto",
    "CitationMetadataApiDto",
    "ConnectionApiDto",
    "ConnectionSettingsApiDto",
    "CreateConnectionRequest",
    "CreateConnectionResponse",
    "CreateFileSystemResponse",
    "CreateFolderRequest",
    "CreateFolderResponse",
    "CreateFolderResponseV2",
    "CreateIndexingScheduleRequest",
    "CreateIndexingScheduleResponse",
    "CreateIndexingTaskRequest",
    "CreateIndexingTaskResponse",
    "CreateManagedFileSystemRequest",
    "CreateRemoteFileSystemRequest",
    "CreateTagRequest",
    "CreateTagResponse",
    "CronTrigger",
    "ExecutionTriggerReason",
    "FileSystemApiDto",
    "FileSystemRootMetadataApiDto",
    "GetCitationOutputUriResponse",
    "GetConnectionResponse",
    "GetIndexerResponse",
    "GetIndexingScheduleResponse",
    "GetIndexingTaskResponse",
    "GetMetadataResponse",
    "GetParentResponse",
    "GetParentUriResponse",
    "GetRunEventRatingResponse",
    "GetSignedUrlResponse",
    "GetWorkerEventsResponse",
    "GetWorkerEventsV2Response",
    "GetWorkerMetadataResponse",
    "GetWorkerRunResponse",
    "GetWorkerStatusResponse",
    "GetWorkersResponse",
    "GetWorkflowEventsV3Response",
    "HighlightedTextCitationMetadataApiDto",
    "ImageDetectionBoxApiDto",
    "IndexerDto",
    "IndexingActionDto",
    "IndexingActionStatus",
    "IndexingScheduleDto",
    "IndexingTaskDto",
    "IndexingTaskStatus",
    "InfoEvent",
    "InfoEvent1",
    "IngestEventRequest",
    "IngestEventResponse",
    "InterruptWorkflowRunRequest",
    "IntervalTrigger",
    "InvokeWorkflowCheckpointRequest",
    "InvokeWorkflowCheckpointResponse",
    "JsonNode",
    "JsonNodeType",
    "ListAllFileSystemsResponse",
    "ListFileSystemResponse",
    "ListIndexersResponse",
    "ListIndexingActionsResponse",
    "ListIndexingSchedulesResponse",
    "ListScheduleExecutionsResponse",
    "ListTagsResponse",
    "ListUsersResponse",
    "ManagedFileSystemApiDto",
    "MeResponse",
    "ModelSchema",
    "OnUploadTrigger",
    "PagedListFileSystemResponse",
    "PersistenceMode",
    "PostRatingRequest",
    "PostRunEventRatingResponse",
    "PostWorkerRunRequest",
    "PostWorkerRunResponse",
    "PostWorkflowRunRequest",
    "PostWorkflowRunResponse",
    "ProgressEvent",
    "ProgressEvent1",
    "RatingDtoWorkerRunEventRatingSecondaryId",
    "RemoteFileSystemApiDto",
    "RemoveTagFromFileRequest",
    "RequestForInputEvent",
    "ResourceEntryDto",
    "ResourceIdentifier",
    "ResourceMetadataDto",
    "ResourceTypeDto",
    "RunStatusDto",
    "S3ConnectionSettingsApiDto",
    "S3FileSystemRootMetadataApiDto",
    "ScheduleExecutionDto",
    "ScheduleTrigger",
    "SchemaLocation",
    "StartExecutionResponse",
    "TagInfo",
    "UpdateIndexingScheduleRequest",
    "UpdateIndexingScheduleResponse",
    "UpdateTagRequest",
    "UpdateTagResponse",
    "UploadFileToManagedFileSystemResponse",
    "UploadResourceResponseV2",
    "UserInfoResponse",
    "UserInputEvent",
    "UserRequestForInputEvent",
    "WebPageCitationMetadataApiDto",
    "WorkerEvent",
    "WorkerEventV2",
    "WorkerMetadataDto",
    "WorkerRunEventRatingSecondaryId",
    "WorkerV2NextPageToken",
    "WorkflowStatusResponse",
]

# import apis into sdk package
from perceptic_core_client.api.citations_resource_api import CitationsResourceApi as CitationsResourceApi
from perceptic_core_client.api.connection_resource_api import ConnectionResourceApi as ConnectionResourceApi
from perceptic_core_client.api.file_system_contents_resource_api import FileSystemContentsResourceApi as FileSystemContentsResourceApi
from perceptic_core_client.api.file_system_resource_api import FileSystemResourceApi as FileSystemResourceApi
from perceptic_core_client.api.indexer_resource_api import IndexerResourceApi as IndexerResourceApi
from perceptic_core_client.api.indexing_schedule_resource_api import IndexingScheduleResourceApi as IndexingScheduleResourceApi
from perceptic_core_client.api.indexing_task_resource_api import IndexingTaskResourceApi as IndexingTaskResourceApi
from perceptic_core_client.api.tag_resource_api import TagResourceApi as TagResourceApi
from perceptic_core_client.api.uri_resource_api import UriResourceApi as UriResourceApi
from perceptic_core_client.api.user_resource_api import UserResourceApi as UserResourceApi
from perceptic_core_client.api.worker_resource_api import WorkerResourceApi as WorkerResourceApi
from perceptic_core_client.api.workflow_resource_v3_api import WorkflowResourceV3Api as WorkflowResourceV3Api

# import ApiClient
from perceptic_core_client.api_response import ApiResponse as ApiResponse
from perceptic_core_client.api_client import ApiClient as ApiClient
from perceptic_core_client.configuration import Configuration as Configuration
from perceptic_core_client.exceptions import OpenApiException as OpenApiException
from perceptic_core_client.exceptions import ApiTypeError as ApiTypeError
from perceptic_core_client.exceptions import ApiValueError as ApiValueError
from perceptic_core_client.exceptions import ApiKeyError as ApiKeyError
from perceptic_core_client.exceptions import ApiAttributeError as ApiAttributeError
from perceptic_core_client.exceptions import ApiException as ApiException

# import models into sdk package
from perceptic_core_client.models.action_type import ActionType as ActionType
from perceptic_core_client.models.add_tag_to_file_request import AddTagToFileRequest as AddTagToFileRequest
from perceptic_core_client.models.azure_blob_connection_settings_api_dto import AzureBlobConnectionSettingsApiDto as AzureBlobConnectionSettingsApiDto
from perceptic_core_client.models.azure_blob_file_system_root_metadata_api_dto import AzureBlobFileSystemRootMetadataApiDto as AzureBlobFileSystemRootMetadataApiDto
from perceptic_core_client.models.biotech_analysis_api_dto import BiotechAnalysisApiDto as BiotechAnalysisApiDto
from perceptic_core_client.models.biotech_analysis_image_annotated_citation_api_dto import BiotechAnalysisImageAnnotatedCitationApiDto as BiotechAnalysisImageAnnotatedCitationApiDto
from perceptic_core_client.models.bulk_get_citations_request import BulkGetCitationsRequest as BulkGetCitationsRequest
from perceptic_core_client.models.bulk_get_citations_response import BulkGetCitationsResponse as BulkGetCitationsResponse
from perceptic_core_client.models.citation_api_dto import CitationApiDto as CitationApiDto
from perceptic_core_client.models.citation_metadata_api_dto import CitationMetadataApiDto as CitationMetadataApiDto
from perceptic_core_client.models.connection_api_dto import ConnectionApiDto as ConnectionApiDto
from perceptic_core_client.models.connection_settings_api_dto import ConnectionSettingsApiDto as ConnectionSettingsApiDto
from perceptic_core_client.models.create_connection_request import CreateConnectionRequest as CreateConnectionRequest
from perceptic_core_client.models.create_connection_response import CreateConnectionResponse as CreateConnectionResponse
from perceptic_core_client.models.create_file_system_response import CreateFileSystemResponse as CreateFileSystemResponse
from perceptic_core_client.models.create_folder_request import CreateFolderRequest as CreateFolderRequest
from perceptic_core_client.models.create_folder_response import CreateFolderResponse as CreateFolderResponse
from perceptic_core_client.models.create_folder_response_v2 import CreateFolderResponseV2 as CreateFolderResponseV2
from perceptic_core_client.models.create_indexing_schedule_request import CreateIndexingScheduleRequest as CreateIndexingScheduleRequest
from perceptic_core_client.models.create_indexing_schedule_response import CreateIndexingScheduleResponse as CreateIndexingScheduleResponse
from perceptic_core_client.models.create_indexing_task_request import CreateIndexingTaskRequest as CreateIndexingTaskRequest
from perceptic_core_client.models.create_indexing_task_response import CreateIndexingTaskResponse as CreateIndexingTaskResponse
from perceptic_core_client.models.create_managed_file_system_request import CreateManagedFileSystemRequest as CreateManagedFileSystemRequest
from perceptic_core_client.models.create_remote_file_system_request import CreateRemoteFileSystemRequest as CreateRemoteFileSystemRequest
from perceptic_core_client.models.create_tag_request import CreateTagRequest as CreateTagRequest
from perceptic_core_client.models.create_tag_response import CreateTagResponse as CreateTagResponse
from perceptic_core_client.models.cron_trigger import CronTrigger as CronTrigger
from perceptic_core_client.models.execution_trigger_reason import ExecutionTriggerReason as ExecutionTriggerReason
from perceptic_core_client.models.file_system_api_dto import FileSystemApiDto as FileSystemApiDto
from perceptic_core_client.models.file_system_root_metadata_api_dto import FileSystemRootMetadataApiDto as FileSystemRootMetadataApiDto
from perceptic_core_client.models.get_citation_output_uri_response import GetCitationOutputUriResponse as GetCitationOutputUriResponse
from perceptic_core_client.models.get_connection_response import GetConnectionResponse as GetConnectionResponse
from perceptic_core_client.models.get_indexer_response import GetIndexerResponse as GetIndexerResponse
from perceptic_core_client.models.get_indexing_schedule_response import GetIndexingScheduleResponse as GetIndexingScheduleResponse
from perceptic_core_client.models.get_indexing_task_response import GetIndexingTaskResponse as GetIndexingTaskResponse
from perceptic_core_client.models.get_metadata_response import GetMetadataResponse as GetMetadataResponse
from perceptic_core_client.models.get_parent_response import GetParentResponse as GetParentResponse
from perceptic_core_client.models.get_parent_uri_response import GetParentUriResponse as GetParentUriResponse
from perceptic_core_client.models.get_run_event_rating_response import GetRunEventRatingResponse as GetRunEventRatingResponse
from perceptic_core_client.models.get_signed_url_response import GetSignedUrlResponse as GetSignedUrlResponse
from perceptic_core_client.models.get_worker_events_response import GetWorkerEventsResponse as GetWorkerEventsResponse
from perceptic_core_client.models.get_worker_events_v2_response import GetWorkerEventsV2Response as GetWorkerEventsV2Response
from perceptic_core_client.models.get_worker_metadata_response import GetWorkerMetadataResponse as GetWorkerMetadataResponse
from perceptic_core_client.models.get_worker_run_response import GetWorkerRunResponse as GetWorkerRunResponse
from perceptic_core_client.models.get_worker_status_response import GetWorkerStatusResponse as GetWorkerStatusResponse
from perceptic_core_client.models.get_workers_response import GetWorkersResponse as GetWorkersResponse
from perceptic_core_client.models.get_workflow_events_v3_response import GetWorkflowEventsV3Response as GetWorkflowEventsV3Response
from perceptic_core_client.models.highlighted_text_citation_metadata_api_dto import HighlightedTextCitationMetadataApiDto as HighlightedTextCitationMetadataApiDto
from perceptic_core_client.models.image_detection_box_api_dto import ImageDetectionBoxApiDto as ImageDetectionBoxApiDto
from perceptic_core_client.models.indexer_dto import IndexerDto as IndexerDto
from perceptic_core_client.models.indexing_action_dto import IndexingActionDto as IndexingActionDto
from perceptic_core_client.models.indexing_action_status import IndexingActionStatus as IndexingActionStatus
from perceptic_core_client.models.indexing_schedule_dto import IndexingScheduleDto as IndexingScheduleDto
from perceptic_core_client.models.indexing_task_dto import IndexingTaskDto as IndexingTaskDto
from perceptic_core_client.models.indexing_task_status import IndexingTaskStatus as IndexingTaskStatus
from perceptic_core_client.models.info_event import InfoEvent as InfoEvent
from perceptic_core_client.models.info_event1 import InfoEvent1 as InfoEvent1
from perceptic_core_client.models.ingest_event_request import IngestEventRequest as IngestEventRequest
from perceptic_core_client.models.ingest_event_response import IngestEventResponse as IngestEventResponse
from perceptic_core_client.models.interrupt_workflow_run_request import InterruptWorkflowRunRequest as InterruptWorkflowRunRequest
from perceptic_core_client.models.interval_trigger import IntervalTrigger as IntervalTrigger
from perceptic_core_client.models.invoke_workflow_checkpoint_request import InvokeWorkflowCheckpointRequest as InvokeWorkflowCheckpointRequest
from perceptic_core_client.models.invoke_workflow_checkpoint_response import InvokeWorkflowCheckpointResponse as InvokeWorkflowCheckpointResponse
from perceptic_core_client.models.json_node import JsonNode as JsonNode
from perceptic_core_client.models.json_node_type import JsonNodeType as JsonNodeType
from perceptic_core_client.models.list_all_file_systems_response import ListAllFileSystemsResponse as ListAllFileSystemsResponse
from perceptic_core_client.models.list_file_system_response import ListFileSystemResponse as ListFileSystemResponse
from perceptic_core_client.models.list_indexers_response import ListIndexersResponse as ListIndexersResponse
from perceptic_core_client.models.list_indexing_actions_response import ListIndexingActionsResponse as ListIndexingActionsResponse
from perceptic_core_client.models.list_indexing_schedules_response import ListIndexingSchedulesResponse as ListIndexingSchedulesResponse
from perceptic_core_client.models.list_schedule_executions_response import ListScheduleExecutionsResponse as ListScheduleExecutionsResponse
from perceptic_core_client.models.list_tags_response import ListTagsResponse as ListTagsResponse
from perceptic_core_client.models.list_users_response import ListUsersResponse as ListUsersResponse
from perceptic_core_client.models.managed_file_system_api_dto import ManagedFileSystemApiDto as ManagedFileSystemApiDto
from perceptic_core_client.models.me_response import MeResponse as MeResponse
from perceptic_core_client.models.model_schema import ModelSchema as ModelSchema
from perceptic_core_client.models.on_upload_trigger import OnUploadTrigger as OnUploadTrigger
from perceptic_core_client.models.paged_list_file_system_response import PagedListFileSystemResponse as PagedListFileSystemResponse
from perceptic_core_client.models.persistence_mode import PersistenceMode as PersistenceMode
from perceptic_core_client.models.post_rating_request import PostRatingRequest as PostRatingRequest
from perceptic_core_client.models.post_run_event_rating_response import PostRunEventRatingResponse as PostRunEventRatingResponse
from perceptic_core_client.models.post_worker_run_request import PostWorkerRunRequest as PostWorkerRunRequest
from perceptic_core_client.models.post_worker_run_response import PostWorkerRunResponse as PostWorkerRunResponse
from perceptic_core_client.models.post_workflow_run_request import PostWorkflowRunRequest as PostWorkflowRunRequest
from perceptic_core_client.models.post_workflow_run_response import PostWorkflowRunResponse as PostWorkflowRunResponse
from perceptic_core_client.models.progress_event import ProgressEvent as ProgressEvent
from perceptic_core_client.models.progress_event1 import ProgressEvent1 as ProgressEvent1
from perceptic_core_client.models.rating_dto_worker_run_event_rating_secondary_id import RatingDtoWorkerRunEventRatingSecondaryId as RatingDtoWorkerRunEventRatingSecondaryId
from perceptic_core_client.models.remote_file_system_api_dto import RemoteFileSystemApiDto as RemoteFileSystemApiDto
from perceptic_core_client.models.remove_tag_from_file_request import RemoveTagFromFileRequest as RemoveTagFromFileRequest
from perceptic_core_client.models.request_for_input_event import RequestForInputEvent as RequestForInputEvent
from perceptic_core_client.models.resource_entry_dto import ResourceEntryDto as ResourceEntryDto
from perceptic_core_client.models.resource_identifier import ResourceIdentifier as ResourceIdentifier
from perceptic_core_client.models.resource_metadata_dto import ResourceMetadataDto as ResourceMetadataDto
from perceptic_core_client.models.resource_type_dto import ResourceTypeDto as ResourceTypeDto
from perceptic_core_client.models.run_status_dto import RunStatusDto as RunStatusDto
from perceptic_core_client.models.s3_connection_settings_api_dto import S3ConnectionSettingsApiDto as S3ConnectionSettingsApiDto
from perceptic_core_client.models.s3_file_system_root_metadata_api_dto import S3FileSystemRootMetadataApiDto as S3FileSystemRootMetadataApiDto
from perceptic_core_client.models.schedule_execution_dto import ScheduleExecutionDto as ScheduleExecutionDto
from perceptic_core_client.models.schedule_trigger import ScheduleTrigger as ScheduleTrigger
from perceptic_core_client.models.schema_location import SchemaLocation as SchemaLocation
from perceptic_core_client.models.start_execution_response import StartExecutionResponse as StartExecutionResponse
from perceptic_core_client.models.tag_info import TagInfo as TagInfo
from perceptic_core_client.models.update_indexing_schedule_request import UpdateIndexingScheduleRequest as UpdateIndexingScheduleRequest
from perceptic_core_client.models.update_indexing_schedule_response import UpdateIndexingScheduleResponse as UpdateIndexingScheduleResponse
from perceptic_core_client.models.update_tag_request import UpdateTagRequest as UpdateTagRequest
from perceptic_core_client.models.update_tag_response import UpdateTagResponse as UpdateTagResponse
from perceptic_core_client.models.upload_file_to_managed_file_system_response import UploadFileToManagedFileSystemResponse as UploadFileToManagedFileSystemResponse
from perceptic_core_client.models.upload_resource_response_v2 import UploadResourceResponseV2 as UploadResourceResponseV2
from perceptic_core_client.models.user_info_response import UserInfoResponse as UserInfoResponse
from perceptic_core_client.models.user_input_event import UserInputEvent as UserInputEvent
from perceptic_core_client.models.user_request_for_input_event import UserRequestForInputEvent as UserRequestForInputEvent
from perceptic_core_client.models.web_page_citation_metadata_api_dto import WebPageCitationMetadataApiDto as WebPageCitationMetadataApiDto
from perceptic_core_client.models.worker_event import WorkerEvent as WorkerEvent
from perceptic_core_client.models.worker_event_v2 import WorkerEventV2 as WorkerEventV2
from perceptic_core_client.models.worker_metadata_dto import WorkerMetadataDto as WorkerMetadataDto
from perceptic_core_client.models.worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId as WorkerRunEventRatingSecondaryId
from perceptic_core_client.models.worker_v2_next_page_token import WorkerV2NextPageToken as WorkerV2NextPageToken
from perceptic_core_client.models.workflow_status_response import WorkflowStatusResponse as WorkflowStatusResponse

