# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.models.post_run_event_rating_response import PostRunEventRatingResponse

class TestPostRunEventRatingResponse(unittest.TestCase):
    """PostRunEventRatingResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PostRunEventRatingResponse:
        """Test PostRunEventRatingResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PostRunEventRatingResponse`
        """
        model = PostRunEventRatingResponse()
        if include_optional:
            return PostRunEventRatingResponse(
                rating = perceptic_core_client.models.rating_dto_worker_run_event_rating_secondary_id.RatingDtoWorkerRunEventRatingSecondaryId(
                    id = '62ECB020-8429-30cc-01FF-CCfeEe150AC3', 
                    grade = 1.337, 
                    written_feedback = '', 
                    secondary_id = perceptic_core_client.models.worker_run_event_rating_secondary_id.WorkerRunEventRatingSecondaryId(
                        run_rid = '', 
                        sequence = 56, ), )
            )
        else:
            return PostRunEventRatingResponse(
        )
        """

    def testPostRunEventRatingResponse(self):
        """Test PostRunEventRatingResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
