# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from uuid import UUID
from perceptic_core_client.models.worker_run_event_rating_secondary_id import WorkerRunEventRatingSecondaryId
from typing import Optional, Set
from typing_extensions import Self

class RatingDtoWorkerRunEventRatingSecondaryId(BaseModel):
    """
    RatingDtoWorkerRunEventRatingSecondaryId
    """ # noqa: E501
    id: Optional[UUID] = None
    grade: Optional[Union[StrictFloat, StrictInt]] = None
    written_feedback: Optional[StrictStr] = Field(default=None, alias="writtenFeedback")
    secondary_id: Optional[WorkerRunEventRatingSecondaryId] = Field(default=None, alias="secondaryId")
    __properties: ClassVar[List[str]] = ["id", "grade", "writtenFeedback", "secondaryId"]

    @field_validator('id')
    def id_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}", value):
            raise ValueError(r"must validate the regular expression /[a-fA-F0-9]{8}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{4}-[a-fA-F0-9]{12}/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of RatingDtoWorkerRunEventRatingSecondaryId from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of secondary_id
        if self.secondary_id:
            _dict['secondaryId'] = self.secondary_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of RatingDtoWorkerRunEventRatingSecondaryId from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "id": obj.get("id"),
            "grade": obj.get("grade"),
            "writtenFeedback": obj.get("writtenFeedback"),
            "secondaryId": WorkerRunEventRatingSecondaryId.from_dict(obj["secondaryId"]) if obj.get("secondaryId") is not None else None
        })
        return _obj


