# coding: utf-8

"""
    perceptic-core-server API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 0.0.1-SNAPSHOT
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from perceptic_core_client.api.workflow_resource_v3_api import WorkflowResourceV3Api


class TestWorkflowResourceV3Api(unittest.TestCase):
    """WorkflowResourceV3Api unit test stubs"""

    def setUp(self) -> None:
        self.api = WorkflowResourceV3Api()

    def tearDown(self) -> None:
        pass

    def test_api_v3_workflows_workflow_id_runs_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_post

        Start Workflow Run
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_cancel_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_cancel_post

        Interrupt
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_checkpoints_checkpoint_name_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_checkpoints_checkpoint_name_post

        Invoke Checkpoint
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_events_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_events_get

        Get Run Events
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_get

        Get Workflow Status
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_stream_get(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_stream_get

        Stream Run
        """
        pass

    def test_api_v3_workflows_workflow_id_runs_run_rid_user_input_post(self) -> None:
        """Test case for api_v3_workflows_workflow_id_runs_run_rid_user_input_post

        Submit User Input
        """
        pass


if __name__ == '__main__':
    unittest.main()
